@@ -4,20 +4,21 @@
 # License           : MIT license <Check LICENSE>
 # Author            : Anderson Ignacio da Silva (aignacio) <anderson@aignacio.com>
 # Date              : 06.02.2023
-# Last Modified Date: 17.03.2023
+# Last Modified Date: 08.04.2023
 import logging
 import os
 import abc
 from tabulate import tabulate
 from jinja2 import Environment, FileSystemLoader
-import ipsocgen
+
+__IPSOCGEN_VERSION__ = '0.1.9'
 
 class options:
     TYPES               = ['soc', 'mpsoc']
-    sch_cfg             = os.path.join(os.path.dirname(ipsocgen.__file__),'common/schemas/schema_config.yaml')
-    sch_master          = os.path.join(os.path.dirname(ipsocgen.__file__),'common/schemas/schema_master.yaml')
-    sch_slave           = os.path.join(os.path.dirname(ipsocgen.__file__),'common/schemas/schema_slave.yaml')
-    tmpl_folder         = os.path.join(os.path.dirname(ipsocgen.__file__),'common/templates')
+    sch_cfg             = os.path.join(os.path.dirname(__file__),'schemas/schema_config.yaml')
+    sch_master          = os.path.join(os.path.dirname(__file__),'schemas/schema_master.yaml')
+    sch_slave           = os.path.join(os.path.dirname(__file__),'schemas/schema_slave.yaml')
+    tmpl_folder         = os.path.join(os.path.dirname(__file__),'templates')
     tmpl_axi4_cross_bar = 'axi4_crossbar.txt'
     tmpl_nox            = 'nox_wrapper.txt'
     tmpl_axi4_mem_ram   = 'axi4_mem_ram.txt'
