@@ -4,13 +4,13 @@
 # License           : MIT license <Check LICENSE>
 # Author            : Anderson Ignacio da Silva (aignacio) <anderson@aignacio.com>
 # Date              : 20.02.2023
-# Last Modified Date: 17.03.2023
+# Last Modified Date: 08.04.2023
 import logging
 import os
 import sys
 import shutil
-from ipsocgen.common.constants import options,base_module
-from ipsocgen.common.modules import *
+from common.constants import options,base_module
+from common.modules import *
 from tabulate import tabulate
 from jinja2 import Environment, FileSystemLoader
 
@@ -133,6 +133,7 @@ def soc_gen(soc, soc_name, desc, output, mmap):
     global_rtl += '\nendmodule'
 
     _gen_design_files(soc_name, global_rtl, hdl_obj, output)
+    _gen_header_files(soc_name, bus, hdl_obj, output)
 
     soc_data = {}
     soc_data['name'] = soc_name
@@ -147,7 +148,6 @@ def _gen_design_files(soc_name, global_rtl, hdl_obj, out_dir):
         types.add(obj.get_acc_type())
 
     out_rtl = os.path.join(out_dir,'rtl')
-    out_ips = os.path.join(out_dir,'ips')
 
     if not os.path.exists(out_dir):
         os.mkdir(out_dir)
@@ -155,19 +155,57 @@ def _gen_design_files(soc_name, global_rtl, hdl_obj, out_dir):
     if not os.path.exists(out_rtl):
         os.mkdir(out_rtl)
         logging.debug('Creating RTL directory: '+str(out_rtl))
-    if not os.path.exists(out_ips):
-        os.mkdir(out_ips)
-        logging.debug('Creating IPs directory: '+str(out_ips))
-
-        # logging.warning('Overwriting previous '+str(out_dir)+' directory')
-        # shutil.rmtree(out_dir)
-        # os.mkdir(out_dir)
 
     rtl_out = os.path.join(out_rtl,soc_name+'.sv')
     soc_rtl = open(rtl_out, "w")
     soc_rtl.write(global_rtl)
     soc_rtl.close()
 
+def _gen_header_files(soc_name, bus, hdl_obj, out_dir):
+    types = set()
+    # Creates a set without repeated acc types
+    for obj in hdl_obj:
+        types.add(obj.get_acc_type())
+
+    out_sw = os.path.join(out_dir,'sw')
+
+    if not os.path.exists(out_dir):
+        os.mkdir(out_dir)
+        logging.debug('Creating output directory: '+str(out_dir))
+    if not os.path.exists(out_sw):
+        os.mkdir(out_sw)
+        logging.debug('Creating SW directory: '+str(out_sw))
+
+    header_out = os.path.join(out_sw, soc_name+'.h')
+    header_file = open(header_out, "w")
+    header_file.write('#ifndef '+soc_name.upper()+'_H')
+    header_file.write('\n#define '+soc_name.upper()+'_H')
+    header_file.write('\n\n')
+    header_file.write('// AUTO-GENERATED header file through IPSoCGen')
+    header_file.write('\n// '+datetime.now().strftime('%d/%m/%Y %H:%M:%S'))
+    header_file.write('\n\n')
+    header_file.write(tabulate(bus.table_masters_c, tablefmt="plain"))
+    header_file.write('\n\n')
+    header_file.write(tabulate(bus.table_slaves_c, tablefmt="plain"))
+    header_file.write('\n\n')
+
+    table = []
+    for slave in range(len(bus.description)):
+        slave_info = _fmt_base_addr(bus.description[slave], bus.base_addr_h[slave])
+        table.append(['#define', slave_info['desc'], '0x'+slave_info['baddr']])
+    header_file.write(tabulate(table, ['//', 'SLAVE', 'BASE ADDRESS'], tablefmt='plain'))
+    header_file.write('\n')
+
+    header_file.write('\n#endif')
+    header_file.close()
+
+def _fmt_base_addr(description, base_address):
+    info  = {}
+    desc  = str(description).replace(' ','_')+'_BASE_ADDR'
+    info['desc']  = desc.upper()
+    info['baddr'] = str(base_address)
+    return info
+
 def _soc_slaves(bus, soc, soc_cfg, dma_info):
     hdl_obj = []
     mmap = bus.get_mmap()
