@@ -4,11 +4,11 @@
 # License           : MIT license <Check LICENSE>
 # Author            : Anderson Ignacio da Silva (aignacio) <anderson@aignacio.com>
 # Date              : 06.02.2023
-# Last Modified Date: 17.03.2023
+# Last Modified Date: 08.04.2023
 import logging
 import os
 import sys
-from ipsocgen.common.constants import options,base_module
+from common.constants import options,base_module
 from tabulate import tabulate
 from jinja2 import Environment, FileSystemLoader
 from datetime import datetime
@@ -139,7 +139,8 @@ class Axi4Bus(base_module):
         file_loader = FileSystemLoader(options.tmpl_folder)
         env = Environment(loader=file_loader)
         template = env.get_template(options.tmpl_axi4_cross_bar)
-        output =  tabulate(self.table_masters_c, tablefmt="plain")
+        output = '\n'
+        output +=  tabulate(self.table_masters_c, tablefmt="plain")
         output += '\n\n'
         output += tabulate(self.table_slaves_c, tablefmt="plain")
         output += template.render(axi4bus=self)
@@ -237,8 +238,8 @@ class Axi4UART(base_module):
         self.io_tx        = cfg['io_tx']
         self.irq_uart_rx  = cfg['irq_uart_rx']
         self.signals.append('  logic '+self.irq_uart_rx+';')
-        self.signals.append('  logic '+self.io_tx+'; // IO Pin')
-        self.signals.append('  logic '+self.io_rx+'; // IO Pin')
+        # self.signals.append('  logic '+self.io_tx+'; // IO Pin')
+        # self.signals.append('  logic '+self.io_rx+'; // IO Pin')
         self.io['in'].append(['logic', cfg['io_rx']])
         self.io['out'].append(['logic', cfg['io_tx']])
         self.acc_type     = 'acc_uart'
@@ -298,7 +299,7 @@ class Axi4RstCtrl(base_module):
         self.io_bootloader   = cfg['io_bootloader']
         self.io_in_rst       = cfg['io_in_rst']
         self.rst_in_type     = cfg['rst_in_type']
-        self.signals.append('  logic '+self.io_bootloader+'; // IO Pin')
+        # self.signals.append('  logic '+self.io_bootloader+'; // IO Pin')
         self.io['in'].append(['logic', cfg['io_bootloader']])
         self.io['in'].append(['logic', cfg['io_in_rst']])
         self.acc_type        = 'acc_rst'
@@ -316,6 +317,7 @@ class Clock(base_module):
             self.clkin_period  = clk_cfg['pll']['clkin_period']
             self.io_clk_MHz    = clk_cfg['io_clk_MHz']
             self.clk_int       = clk_cfg['clk_int']
+            self.signals.append('  logic '+self.clk_int+';')
             self.io['in'].append(['logic', clk_cfg['io_clk_MHz']])
             self.io['in'].append(['logic', clk_cfg['pll']['io_rst_pin']])
         else:
@@ -351,6 +353,7 @@ class Reset(base_module):
         else:
             super().__init__(rst_cfg['name'], 0, 0, options.tmpl_rst)
             self.io['in'].append(['logic', rst_cfg['io_in_rst']])
+            self.signals.append('  logic '+rst_cfg['rst_int']+';')
 
 class ModuleHeader(base_module):
     def __init__(self, type_cfg, name, desc, io_list, defines):
