@@ -3,7 +3,7 @@ import argparse
 import pathlib
 import sys
 import yaml
-from ipsocgen.common.constants import options, CustomFormatter
+from common.constants import options, CustomFormatter
 from cerberus import Validator
 
 def validate_config(args):
